@@ -3,7 +3,8 @@ use warnings;
 use strict;
 use UNIVERSAL::require;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+our $SKIP_UTF8_DOUBLE_ENCODE_CHECK = 0;
 
 sub request {
     my $self = shift;
@@ -255,6 +256,29 @@ All parameters can be get/set using accessor methods. E.g.
  my $consumer_key = $request->consumer_key;
  $request->request_method('POST');
 
+=head2 THE REQUEST_URL PARAMETER
+
+Any query parameters in the request_url are removed and added to the extra_params hash when generating the signature.
+
+E.g. the following requests are equivalent:
+
+    my $request = Net::OAuth->request('user auth')->new(
+        token => 'abcdef',
+        request_url => 'http://example.com/auth',
+        extra_params => {
+                foo => 'bar',
+        },
+    );
+
+    my $request = Net::OAuth->request('user auth')->new(
+        token => 'abcdef',
+        request_url => 'http://example.com/auth?foo=bar',
+    );
+
+If you want to get the request_url with the query parameters removed, you can do:
+
+    my $url = $request->normalized_request_url;
+
 =head2 SIGNATURE METHODS
 
 The following signature methods are supported:
@@ -327,6 +351,36 @@ To send a request without including a token, use a Consumer Request:
 
 See L<Net::OAuth::ConsumerRequest>
 
+=head2 I18N
+
+Per the OAuth spec, when making the signature Net::OAuth first encodes
+parameters to UTF-8. This means that any parameters you pass to Net::OAuth,
+if they are outside of ASCII character set, should be run through
+Encode::decode() (or an equivalent PerlIO layer) first to decode them to
+perl's internal character sructure.
+
+There is a check in Net::OAuth's parameter encoding function that guesses if
+the data you are passing in looks like it is already UTF-8 and warns that you
+should decode it first. This accidental double-encoding of UTF-8 may be a
+source of headaches - if you find that the signature check is failing when
+you send non-ASCII data, that is a likely cause. 
+
+You can silence this warning by setting:
+
+    $Net::OAuth::SKIP_UTF8_DOUBLE_ENCODE_CHECK = 1;
+
+Following is an example of decoding some UTF-8 form data before sending it in
+an OAuth messaage (from the Twitter demo included in the Net::OAuth package):
+
+my $request = Net::OAuth->request("protected resource")->new(
+    $self->_default_request_params,
+    request_url => 'http://twitter.com/statuses/update.xml',
+    token => $self->session->param('token'),
+    token_secret => $self->session->param('token_secret'),
+    request_method => 'POST',
+    extra_params => {status => decode_utf8($self->query->param('status'))}
+);
+
 =head1 DEMO
 
 There is a demo Consumer CGI in this package, also available online at L<http://oauth.kg23.com/>
